class Conference < ApplicationRecord
  has_many :sessions
  has_many :speakers
  has_many :stages
  has_many :revision_sets

  serialize :data, coder: JSON

  validates :time_zone, presence: true, inclusion: { in: ActiveSupport::TimeZone.all.map(&:name) }

  def days
    (starts_at.to_date..ends_at.to_date)
  end

  def to_param
    slug
  end

  def starts_at_in_local_time
    starts_at.in_time_zone(time_zone || 'UTC')
  end

  def ends_at_in_local_time
    ends_at.in_time_zone(time_zone || 'UTC')
  end
end
