Rails.application.routes.draw do
  mount Crono::Engine, at: '/crono'
  mount ActionCable.server => '/cable'

  get 'speakers/show'

  get 'login', to: 'users#login', as: :login
  post 'login', to: 'users#login'
  post 'logout', to: 'users#logout', as: :logout
  get 'profile', to: 'users#profile', as: :profile
  patch 'profile', to: 'users#update_profile', as: :update_profile
  resources :users, only: [:show]
  # Define your application routes per the DSL in https://guides.rubyonrails.org/routing.html

  # Reveal health status on /up that returns 200 if the app boots with no exceptions, otherwise 500.
  # Can be used by load balancers and uptime monitors to verify that the app is live.
  get "up" => "rails/health#show", as: :rails_health_check

  # Defines the root path route ("/")
  # root "posts#index"
  root "conferences#index"

  resources :conferences, param: :slug do
    get ':date', action: :show, on: :member, as: :date
    resources :sessions, param: :ref_id do
      resources :assignments, only: [:create, :destroy]
    end
    resources :speakers, param: :ref_id
  end

  resources :assignments, only: [:index] do
    get 'for/:user_id', action: 'by_user', on: :collection, as: :user
  end
  resources :sessions, param: :ref_id

  # get 'conferences/:slug', to: 'conferences#show', as: :conference
  # get 'conferences/:slug/:date', to: 'conferences#show', as: :conference_day
  # get 'conferences/:slug/session/:ref_id', to: 'sessions#show', as: :conference_session
  # post 'conferences/:slug/session/:ref_id/assignments', to: 'sessions#assign_user', as: :assign_user_session
  # delete 'conferences/:slug/session/:ref_id/assignments', to: 'sessions#unassign_user', as: :unassign_user_session
  # get 'assignments', to: 'assignments#index', as: :assignments
  # get 'assignments/:user_id', to: 'assignments#index', as: :user_assignments
end
